Module tools

Module tools 

Tool registry and handler trait.

User code registers a ToolHandler for each tool the runtime should be able to execute. The runtime dispatches tool.invoke envelopes by looking up the handler in the ToolRegistry and driving it inside a per-job tokio task with a tokio_util::sync::CancellationToken.

Structs

ToolRegistry
Runtime-owned registry of tools.
ToolRegistryBuilder
Builder for ToolRegistry — accumulate handlers, then build.

Traits

ToolHandler
Application-supplied tool handler.